# Copyright 2022 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from charms.launchpad.base import get_service_config
from charms.launchpad.db import strip_dsn_authentication, update_pgpass
from charms.launchpad.payload import configure_lazr
from charms.reactive import (
    clear_flag,
    endpoint_from_flag,
    hook,
    set_flag,
    when,
    when_not,
    when_not_all,
)
from ols import postgres


@when("launchpad.base.configured", "db.master.available")
@when_not("launchpad.db.configured")
def configure():
    db = endpoint_from_flag("db.master.available")
    config = get_service_config()
    db_primary, db_standby = postgres.get_db_uris(db)
    # XXX cjwatson 2022-09-23: Mangle the connection strings into forms
    # Launchpad understands.  In the long term it would be better to have
    # Launchpad be able to consume unmodified connection strings.
    for dsn in [db_primary] + db_standby:
        update_pgpass(dsn)
    config["db_primary"] = strip_dsn_authentication(db_primary)
    config["db_standby"] = ",".join(
        strip_dsn_authentication(dsn) for dsn in db_standby
    )
    configure_lazr(config, "launchpad-db-lazr.conf", "launchpad-db-lazr.conf")
    set_flag("launchpad.db.configured")


@when("launchpad.db.configured")
@when_not_all("launchpad.base.configured", "db.master.available")
def deconfigure():
    clear_flag("launchpad.db.configured")


@hook("upgrade-charm")
def upgrade_charm():
    clear_flag("launchpad.db.configured")


@when("config.changed")
def config_changed():
    clear_flag("launchpad.db.configured")


@when("db.database.changed", "launchpad.db.configured")
def db_changed():
    clear_flag("launchpad.db.configured")
    clear_flag("db.database.changed")


@hook("{requires:rabbitmq}-relation-changed")
def rabbitmq_relation_changed(*args):
    clear_flag("launchpad.db.configured")
