# Copyright 2022 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os.path
import subprocess

from charmhelpers.core import hookenv, host, templating
from ols import base


def home_dir():
    return os.path.join("/home", base.user())


def ensure_home_dir():
    host.mkdir(home_dir(), owner=base.user(), group=base.user(), perms=0o755)


def get_service_config():
    config = dict(hookenv.config())
    config.update(
        {
            "base_dir": base.base_dir(),
            "code_dir": base.code_dir(),
            "logs_dir": base.logs_dir(),
            "payloads_dir": base.payloads_dir(),
            "user": base.user(),
        }
    )
    return config


def config_file_path(name, secret=False):
    if secret:
        config_dir = os.path.join(base.base_dir(), "secrets")
    else:
        config_dir = os.path.join(base.code_dir(), "production-configs")
    return os.path.join(config_dir, name)


def configure_lazr(config, template, name, secret=False):
    hookenv.log("Writing service configuration.")
    templating.render(
        template,
        config_file_path(name, secret=secret),
        config,
        owner="root",
        group=base.user(),
        perms=0o440 if secret else 0o444,
    )


def configure_cron(config, template):
    hookenv.log("Writing crontab.")
    crontab_path = os.path.join(home_dir(), "crontab")
    templating.render(
        template,
        crontab_path,
        config,
        owner=base.user(),
        group=base.user(),
        perms=0o600,
    )
    subprocess.run(
        ["sudo", "-H", "-u", base.user(), "crontab", crontab_path], check=True
    )
